==> whizard-2.4.1.tar.gz: whizard-2.4.1/src/model_features/models_ut.f90 <==
! WHIZARD 2.4.1 Mar 24 2017
!
! Copyright (C) 1999-2017 by
!     Wolfgang Kilian <kilian@physik.uni-siegen.de>
!     Thorsten Ohl <ohl@physik.uni-wuerzburg.de>
!     Juergen Reuter <juergen.reuter@desy.de>
!
!     with contributions from
!     Fabian Bach <fabian.bach@t-online.de>
!     Bijan Chokoufe <bijan.chokoufe@desy.de>
!     Christian Speckner <cnspeckn@googlemail.com>
!     So Young Shim <soyoung.shim@desy.de>
!     Florian Staub <florian.staub@cern.ch>
!     Christian Weiss <christian.weiss@desy.de>
!     and Hans-Werner Boschmann, Felix Braam,
!     Sebastian Schmidt, So-young Shim, Daniel Wiesler
!
! WHIZARD is free software; you can redistribute it and/or modify it
! under the terms of the GNU General Public License as published by
! the Free Software Foundation; either version 2, or (at your option)
! any later version.
!
! WHIZARD is distributed in the hope that it will be useful, but
! WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
! GNU General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this program; if not, write to the Free Software
! Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! This file has been stripped of most comments.  For documentation, refer
! to the source 'whizard.nw'

module models_ut
  use unit_tests
  use models_uti

  implicit none
  private

  public :: models_test

contains

  subroutine models_test (u, results)
    integer, intent(in) :: u
    type(test_results_t), intent(inout) :: results
    call test (models_1, "models_1", &
         "construct model", &
         u, results)
    call test (models_2, "models_2", &
         "read model", &
         u, results)
    call test (models_3, "models_3", &
         "model instance", &
         u, results)
    call test (models_4, "models_4", &
         "handle decays and polarization", &
         u, results)
    call test (models_5, "models_5", &
         "handle parameters", &
         u, results)
    call test (models_6, "models_6", &
         "read model parameters", &
         u, results)
    call test (models_7, "models_7", &
         "handle schemes", &
         u, results)
  end subroutine models_test


end module models_ut

==> whizard-2.6.4.tar.gz: whizard-2.6.4/src/model_features/models_ut.f90 <==
! WHIZARD 2.6.4 Aug 23 2018
!
! Copyright (C) 1999-2018 by
!     Wolfgang Kilian <kilian@physik.uni-siegen.de>
!     Thorsten Ohl <ohl@physik.uni-wuerzburg.de>
!     Juergen Reuter <juergen.reuter@desy.de>
!
!     with contributions from
!     cf. main AUTHORS file
!
! WHIZARD is free software; you can redistribute it and/or modify it
! under the terms of the GNU General Public License as published by
! the Free Software Foundation; either version 2, or (at your option)
! any later version.
!
! WHIZARD is distributed in the hope that it will be useful, but
! WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
! GNU General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this program; if not, write to the Free Software
! Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! This file has been stripped of most comments.  For documentation, refer
! to the source 'whizard.nw'

module models_ut
  use unit_tests
  use models_uti

  implicit none
  private

  public :: models_test

contains

  subroutine models_test (u, results)
    integer, intent(in) :: u
    type(test_results_t), intent(inout) :: results
    call test (models_1, "models_1", &
         "construct model", &
         u, results)
    call test (models_2, "models_2", &
         "read model", &
         u, results)
    call test (models_3, "models_3", &
         "model instance", &
         u, results)
    call test (models_4, "models_4", &
         "handle decays and polarization", &
         u, results)
    call test (models_5, "models_5", &
         "handle parameters", &
         u, results)
    call test (models_6, "models_6", &
         "read model parameters", &
         u, results)
    call test (models_7, "models_7", &
         "handle schemes", &
         u, results)
    call test (models_8, "models_8", &
         "handle UFO-derived models", &
         u, results)
    call test (models_9, "models_9", &
         "generate UFO-derived model file", &
         u, results)
  end subroutine models_test


end module models_ut
